==> pftpd-0.30.tar.gz: pftpd-0.30/plib/server.h <==
/*
** server.h - IDENT TCP/IP socket server code
**
** Copyright (c) 1997-1999 Peter Eriksson <pen@lysator.liu.se>
**
** This program is free software; you can redistribute it and/or
** modify it as you wish - as long as you don't claim that you wrote
** it.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

#ifndef PLIB_SERVER_H
#define PLIB_SERVER_H

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#include "plib/threads.h"
#ifdef INET6
#include "plib/system.h"
#endif

struct server_info;

typedef struct
{
    int fd;
#ifdef INET6
    union sockunion rsin;	/* Remote address */
    union sockunion lsin;	/* Local address */
#else
    struct sockaddr_in rsin; /* Remote address */
    struct sockaddr_in lsin; /* Local address */
#endif
    struct server_info *sp;
} CLIENT;

typedef struct server_info
{
    int fd;
#ifdef INET6
    union sockunion sin;
#else
    struct sockaddr_in sin;
#endif
    void (*handler)(CLIENT *cp);

    int clients_max;
    int clients_cur;
    pthread_mutex_t clients_mtx;
    pthread_cond_t clients_cv;
    pthread_attr_t ca_detached;
} SERVER;

extern SERVER *
server_init(int fd,
#ifdef INET6
	    char *listen_addr,
	    char *listen_port,
#else
	    UINT32 listen_addr,
	    UINT16 listen_port,
#endif
	    int listen_backlog,
	    int max_clients,
	    void (*handler)(CLIENT *cp));

extern int
server_run_all(SERVER *sp);

extern int
server_run_one(SERVER *sp,
	       int fd,
	       int nofork);

#endif

==> pftpd-1.0.tar.gz: pftpd-1.0/plib/server.h <==
/*
** server.h - IDENT TCP/IP socket server code
**
** Copyright (c) 1997-2000 Peter Eriksson <pen@lysator.liu.se>
**
** This program is free software; you can redistribute it and/or
** modify it as you wish - as long as you don't claim that you wrote
** it.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

#ifndef PLIB_SERVER_H
#define PLIB_SERVER_H

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>

#include "plib/threads.h"
#include "plib/sockaddr.h"

struct server_info;

typedef struct
{
    int fd;
    struct sockaddr_gen rsin; /* Remote address */
    struct sockaddr_gen lsin; /* Local address */
    struct server_info *sp;
} CLIENT;

typedef struct server_info
{
    int fd;
    struct sockaddr_gen sin;
    void (*handler)(CLIENT *cp);

    pthread_mutex_t mtx;
    int state; /* 0 = not running, 1 = starting/started, 2 = stopping */
    pthread_t tid;
    
    int clients_max;
    int clients_cur;
    pthread_mutex_t clients_mtx;
    pthread_cond_t clients_cv;
    pthread_attr_t ca_detached;
} SERVER;


extern SERVER *
server_init(int fd,
	    const struct sockaddr_gen *sg,
	    int listen_backlog,
	    int max_clients,
	    void (*handler)(CLIENT *cp));

extern int
server_start(SERVER *sp);

extern int
server_stop(SERVER *sp);

extern int
server_run_all(SERVER *sp);

extern int
server_run_one(SERVER *sp,
	       int fd,
	       int nofork);

extern void
server_cancel(SERVER *sp);
     
#endif
